@@ -582,13 +582,9 @@ class DataTransform(forms.ModelForm):
         print('Init Data Transform')
 
         super(DataTransform, self).__init__(*args, **kwargs)
-        if self.instance.parent is not None:
-            self.accessory = forms.ModelChoiceField(required=True, queryset=Accessory.objects.all(),
-                                                    widget=forms.HiddenInput(attrs={'class': 'form-control'}),
-                                                    initial=self.instance.accessory.pk)
-        # types = list(
-        #     DataTransformerTypes.objects.all().values_list('type', 'type'))
-        # self.fields['type'] = ChoiceField(choices=tuple(types))
+        if self.fields['parent'] is not None and self.fields['parent'] != '':
+            self.fields['accessory'].initial = str(DataTransformer.objects.get(self.fields['parent'].bound_data().accessory.pk)
+
         try:
             if self.instance.get_children().count() >= 0:
                 print('Adding to child form node: ' + str(self.instance.get_children().count() + 1))
@@ -730,8 +726,7 @@ class DataTransformRoot(forms.ModelForm):
     #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
     def __init__(self, *args, **kwargs):
         super(DataTransformRoot, self).__init__(*args, **kwargs)
-        self.accessory = forms.ModelChoiceField(required=True, queryset=Accessory.objects.all(),
-                                       widget=forms.HiddenInput(attrs={'class': 'form-control'}), initial=self.instance.accessory.pk)
+        self.fields['accessory'].initial = str(self.instance.accessory.pk)
 
         # types = list(
         #     DataTransformerTypes.objects.all().values_list('type', 'type'))
